nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Cap15

Struct Cap15 

#[repr(transparent)]
pub struct Cap15(pub u32);
SCT capture register of capture channel

Tuple Fields

0: u32

Implementations

Source

impl Cap15

pub const fn capn_l(&self) -> u16

When UNIFY = 0, read the 16-bit counter value at which this register was last captured. When UNIFY = 1, read the lower 16 bits of the 32-bit value at which this register was last captured.

pub const fn set_capn_l(&mut self, val: u16)

When UNIFY = 0, read the 16-bit counter value at which this register was last captured. When UNIFY = 1, read the lower 16 bits of the 32-bit value at which this register was last captured.

pub const fn capn_h(&self) -> u16

When UNIFY = 0, read the 16-bit counter value at which this register was last captured. When UNIFY = 1, read the upper 16 bits of the 32-bit value at which this register was last captured.

pub const fn set_capn_h(&mut self, val: u16)

When UNIFY = 0, read the 16-bit counter value at which this register was last captured. When UNIFY = 1, read the upper 16 bits of the 32-bit value at which this register was last captured.