#[repr(transparent)]pub struct Capctrl5(pub u32);Expand description
SCT capture control register
Tuple Fields
0: u32Implementations
Sourceimpl Capctrl5
impl Capctrl5
Sourcepub const fn capconn_l(&self) -> u16
pub const fn capconn_l(&self) -> u16
If bit m is one, event m causes the CAPn_L (UNIFY = 0) or the CAPn (UNIFY = 1) register to be loaded (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of match/captures in this SCT.
Sourcepub const fn set_capconn_l(&mut self, val: u16)
pub const fn set_capconn_l(&mut self, val: u16)
If bit m is one, event m causes the CAPn_L (UNIFY = 0) or the CAPn (UNIFY = 1) register to be loaded (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of match/captures in this SCT.
Sourcepub const fn capconn_h(&self) -> u16
pub const fn capconn_h(&self) -> u16
If bit m is one, event m causes the CAPn_H (UNIFY = 0) register to be loaded (event 0 = bit 16, event 1 = bit 17, etc.). The number of bits = number of match/captures in this SCT.
Sourcepub const fn set_capconn_h(&mut self, val: u16)
pub const fn set_capconn_h(&mut self, val: u16)
If bit m is one, event m causes the CAPn_H (UNIFY = 0) register to be loaded (event 0 = bit 16, event 1 = bit 17, etc.). The number of bits = number of match/captures in this SCT.