nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Res

Struct Res 

#[repr(transparent)]
pub struct Res(pub u32);
SCT conflict resolution register

Tuple Fields

0: u32

Implementations

Source

impl Res

pub const fn o0res(&self) -> O0res

Effect of simultaneous set and clear on output 0.

pub const fn set_o0res(&mut self, val: O0res)

Effect of simultaneous set and clear on output 0.

pub const fn o1res(&self) -> O1res

Effect of simultaneous set and clear on output 1.

pub const fn set_o1res(&mut self, val: O1res)

Effect of simultaneous set and clear on output 1.

pub const fn o2res(&self) -> O2res

Effect of simultaneous set and clear on output 2.

pub const fn set_o2res(&mut self, val: O2res)

Effect of simultaneous set and clear on output 2.

pub const fn o3res(&self) -> O3res

Effect of simultaneous set and clear on output 3.

pub const fn set_o3res(&mut self, val: O3res)

Effect of simultaneous set and clear on output 3.

pub const fn o4res(&self) -> O4res

Effect of simultaneous set and clear on output 4.

pub const fn set_o4res(&mut self, val: O4res)

Effect of simultaneous set and clear on output 4.

pub const fn o5res(&self) -> O5res

Effect of simultaneous set and clear on output 5.

pub const fn set_o5res(&mut self, val: O5res)

Effect of simultaneous set and clear on output 5.

pub const fn o6res(&self) -> O6res

Effect of simultaneous set and clear on output 6.

pub const fn set_o6res(&mut self, val: O6res)

Effect of simultaneous set and clear on output 6.

pub const fn o7res(&self) -> O7res

Effect of simultaneous set and clear on output 7.

pub const fn set_o7res(&mut self, val: O7res)

Effect of simultaneous set and clear on output 7.

pub const fn o8res(&self) -> O8res

Effect of simultaneous set and clear on output 8.

pub const fn set_o8res(&mut self, val: O8res)

Effect of simultaneous set and clear on output 8.

pub const fn o9res(&self) -> O9res

Effect of simultaneous set and clear on output 9.

pub const fn set_o9res(&mut self, val: O9res)

Effect of simultaneous set and clear on output 9.

pub const fn o10res(&self) -> O10res

Effect of simultaneous set and clear on output 10.

pub const fn set_o10res(&mut self, val: O10res)

Effect of simultaneous set and clear on output 10.

pub const fn o11res(&self) -> O11res

Effect of simultaneous set and clear on output 11.

pub const fn set_o11res(&mut self, val: O11res)

Effect of simultaneous set and clear on output 11.

pub const fn o12res(&self) -> O12res

Effect of simultaneous set and clear on output 12.

pub const fn set_o12res(&mut self, val: O12res)

Effect of simultaneous set and clear on output 12.

pub const fn o13res(&self) -> O13res

Effect of simultaneous set and clear on output 13.

pub const fn set_o13res(&mut self, val: O13res)

Effect of simultaneous set and clear on output 13.

pub const fn o14res(&self) -> O14res

Effect of simultaneous set and clear on output 14.

pub const fn set_o14res(&mut self, val: O14res)

Effect of simultaneous set and clear on output 14.

pub const fn o15res(&self) -> O15res

Effect of simultaneous set and clear on output 15.

pub const fn set_o15res(&mut self, val: O15res)

Effect of simultaneous set and clear on output 15.