#[repr(transparent)]pub struct Stop(pub u32);Expand description
SCT stop event select register
Tuple Fields
0: u32Implementations
Sourceimpl Stop
impl Stop
Sourcepub const fn stopmsk_l(&self) -> u16
pub const fn stopmsk_l(&self) -> u16
If bit n is one, event n sets the STOP_L bit in the CTRL register (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of events in this SCT.
Sourcepub const fn set_stopmsk_l(&mut self, val: u16)
pub const fn set_stopmsk_l(&mut self, val: u16)
If bit n is one, event n sets the STOP_L bit in the CTRL register (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of events in this SCT.
Sourcepub const fn stopmsk_h(&self) -> u16
pub const fn stopmsk_h(&self) -> u16
If bit n is one, event n sets the STOP_H bit in the CTRL register (event 0 = bit 16, event 1 = bit 17, etc.). The number of bits = number of events in this SCT.
Sourcepub const fn set_stopmsk_h(&mut self, val: u16)
pub const fn set_stopmsk_h(&mut self, val: u16)
If bit n is one, event n sets the STOP_H bit in the CTRL register (event 0 = bit 16, event 1 = bit 17, etc.). The number of bits = number of events in this SCT.