#[repr(transparent)]pub struct Match2(pub u32);Expand description
SCT match value register of match channels
Tuple Fields
0: u32Implementations
Sourceimpl Match2
impl Match2
Sourcepub const fn matchn_l(&self) -> u16
pub const fn matchn_l(&self) -> u16
When UNIFY = 0, read or write the 16-bit value to be compared to the L counter. When UNIFY = 1, read or write the lower 16 bits of the 32-bit value to be compared to the unified counter.
Sourcepub const fn set_matchn_l(&mut self, val: u16)
pub const fn set_matchn_l(&mut self, val: u16)
When UNIFY = 0, read or write the 16-bit value to be compared to the L counter. When UNIFY = 1, read or write the lower 16 bits of the 32-bit value to be compared to the unified counter.
Sourcepub const fn matchn_h(&self) -> u16
pub const fn matchn_h(&self) -> u16
When UNIFY = 0, read or write the 16-bit value to be compared to the H counter. When UNIFY = 1, read or write the upper 16 bits of the 32-bit value to be compared to the unified counter.
Sourcepub const fn set_matchn_h(&mut self, val: u16)
pub const fn set_matchn_h(&mut self, val: u16)
When UNIFY = 0, read or write the 16-bit value to be compared to the H counter. When UNIFY = 1, read or write the upper 16 bits of the 32-bit value to be compared to the unified counter.