#[repr(transparent)]pub struct OutClr(pub u32);Expand description
SCT output 0 clear register
Tuple Fields
0: u32Implementations
Sourceimpl OutClr
impl OutClr
Sourcepub const fn clr(&self) -> u16
pub const fn clr(&self) -> u16
A 1 in bit m selects event m to clear output n (or set it if SETCLRn = 0x1 or 0x2) event 0 = bit 0, event 1 = bit 1, etc. The number of bits = number of events in this SCT. When the counter is used in bi-directional mode, it is possible to reverse the action specified by the output set and clear registers when counting down, See the OUTPUTCTRL register.
Sourcepub const fn set_clr(&mut self, val: u16)
pub const fn set_clr(&mut self, val: u16)
A 1 in bit m selects event m to clear output n (or set it if SETCLRn = 0x1 or 0x2) event 0 = bit 0, event 1 = bit 1, etc. The number of bits = number of events in this SCT. When the counter is used in bi-directional mode, it is possible to reverse the action specified by the output set and clear registers when counting down, See the OUTPUTCTRL register.